

pcomp
==========

.. currentmodule:: pydl

.. autoclass:: pcomp
   :show-inheritance:

   
     
   

   
   

   .. rubric:: Attributes Summary

   .. autosummary::
   
      ~pcomp.coefficients
      ~pcomp.derived
      ~pcomp.eigenvalues
      ~pcomp.variance

   
   

   
   
   

   
   

   .. rubric:: Attributes Documentation

   
   .. autoattribute:: coefficients
   .. autoattribute:: derived
   .. autoattribute:: eigenvalues
   .. autoattribute:: variance

   
   

   
   
   